@@ -26,17 +26,19 @@ This module implements interface with BAG in skill language
 """
 import laygo2.interface
 
-def export(db, filename, cellname, scale=1e-3, reset_library=False, tech_library=None):
-    skill_str=laygo2.interface.skill.export(db, filename, cellname, scale, reset_library, tech_library)
+
+def export(
+    db, filename, cellname=None, scale=1e-3, reset_library=False, tech_library=None
+):
     """
-    Export design(s) to BAG2.
+    Export a laygo2.object.database.Library object to BAG2.
 
     Parameters
     ----------
-    db: laygo2.database.Library
+    db: laygo2.object.database.Library
         The library database to be exported.
     filename: str, optional
-        The path of the intermediate skill scipt file.
+        The path of the intermediate skill script file.
     cellname: str or List[str]
         The name(s) of cell(s) to be exported.
     scale: float
@@ -48,13 +50,47 @@ def export(db, filename, cellname, scale=1e-3, reset_library=False, tech_library
 
     Returns
     -------
-    str: the string object contains corresponding skill scripts.
-    """
+    str: The generated skill script.
 
+    Example
+    --------
+    >>> import laygo2
+    >>> from laygo2.object.database import Design
+    >>> from laygo2.object.physical import Rect, Pin, Instance, Text
+    >>> # Create a design.
+    >>> dsn = Design(name="mycell", libname="genlib")
+    >>> # Create layout objects.
+    >>> r0 = Rect(xy=[[0, 0], [100, 100]], layer=["M1", "drawing"])
+    >>> p0 = Pin(xy=[[0, 0], [50, 50]], layer=["M1", "pin"], name="P")
+    >>> i0 = Instance(libname="tlib", cellname="t0", name="I0", xy=[0, 0])
+    >>> t0 = Text(xy=[[50, 50], [100, 100]], layer=["text", "drawing"], text="T")
+    >>> # Add the layout objects to the design object.
+    >>> dsn.append(r0)
+    >>> dsn.append(p0)
+    >>> dsn.append(i0)
+    >>> dsn.append(t0)
+    >>> #
+    >>> # Export to BAG.
+    >>> lib = laygo2.object.database.Library(name="mylib")
+    >>> lib.append(dsn)
+    >>> scr = laygo2.interface.bag.export(lib, filename="myscript.il")
+    >>> print(scr)
+    ; (definitions of laygo2 skill functions)
+    ; exporting mylib__mycell
+    cv = _laygo2_open_layout("mylib" "mycell" "layout")
+    _laygo2_generate_rect(cv, list( "M1" "drawing" ), list( list( 0.0000  0.0000  ) list( 0.1000  0.1000  ) ), "None")
+    _laygo2_generate_pin(cv, "P", list( "M1" "pin" ), list( list( 0.0000  0.0000  ) list( 0.0500  0.0500  ) ) )
+    _laygo2_generate_instance(cv, "I0", "tlib", "t0", "layout", list( 0.0000  0.0000  ), "R0", 1, 1, 0, 0, nil, nil)
+    _laygo2_save_and_close_layout(cv)
+
+    """
+    skill_str = laygo2.interface.skill.export(
+        db, filename, cellname, scale, reset_library, tech_library
+    )
     import bag
-    prj=bag.BagProject()
-    prj.impl_db._eval_skill('load("'+filename+'");1\n')
+
+    prj = bag.BagProject()
+    prj.impl_db._eval_skill('load("' + filename + '");1\n')
     print("Your design was generated in Virtuoso.")
 
     return skill_str
-
